@@ -64,6 +64,156 @@
         <translation>مسح</translation>
     </message>
 </context>
+<context>
+    <name>DownloadItem</name>
+    <message>
+        <source>bytes</source>
+        <translation>bytes</translation>
+    </message>
+    <message>
+        <source>KB</source>
+        <translation>KB</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation>MB</translation>
+    </message>
+    <message>
+        <source>bytes/sec</source>
+        <translation>bytes/sec</translation>
+    </message>
+    <message>
+        <source>KB/sec</source>
+        <translation>KB/sec</translation>
+    </message>
+    <message>
+        <source>MB/sec</source>
+        <translation>MB/sec</translation>
+    </message>
+    <message>
+        <source>seconds</source>
+        <translation>seconds</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minutes</translation>
+    </message>
+    <message>
+        <source>%4 %5 remaining</source>
+        <translation>%4 %5 متبقي</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadManager</name>
+    <message numerus="yes">
+        <source>%n Download(s)</source>
+        <translation>
+            <numerusform>التحميل %n</numerusform>
+            <numerusform>التحميل %n</numerusform>
+            <numerusform>التحميل %n</numerusform>
+            <numerusform>التحميل %n</numerusform>
+            <numerusform>التحميل %n</numerusform>
+            <numerusform>التحميل %n</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
+    </message>
+    <message>
+        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
+        <translation>يمكن تحميل الفيديو في أقل من %1  دقيقة بحيث يمكنك اختبار وظيفة التحميل.</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>متابعة</translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>احصل على النسخة الكاملة</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadSettings</name>
+    <message>
+        <source>Change location...</source>
+        <translation>تغيير الموقع...</translation>
+    </message>
+    <message>
+        <source>Choose the download location</source>
+        <translation>اختر موقع التحميل</translation>
+    </message>
+    <message>
+        <source>Download location changed.</source>
+        <translation>موقع التحميل تغير.</translation>
+    </message>
+    <message>
+        <source>Current downloads will still go in the previous location.</source>
+        <translation>التحميل سيتم في الموقع السابق.</translation>
+    </message>
+    <message>
+        <source>Downloading to: %1</source>
+        <translation>التحميل الى:%1</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadView</name>
+    <message>
+        <source>Downloads</source>
+        <translation>التحميلات</translation>
+    </message>
+</context>
+<context>
+    <name>GlobalShortcuts</name>
+    <message>
+        <source>Play</source>
+        <translation>Play</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Play/Pause</source>
+        <translation>Play/Pause</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Stop playing after current track</source>
+        <translation>ايقاف تشغيل المقطع الحالي</translation>
+    </message>
+    <message>
+        <source>Next track</source>
+        <translation>المقطع التالي</translation>
+    </message>
+    <message>
+        <source>Previous track</source>
+        <translation>المقطع السابق</translation>
+    </message>
+    <message>
+        <source>Increase volume</source>
+        <translation>رفع الصوت</translation>
+    </message>
+    <message>
+        <source>Decrease volume</source>
+        <translation>خفض الصوت</translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation>صامت</translation>
+    </message>
+    <message>
+        <source>Seek forward</source>
+        <translation>امام</translation>
+    </message>
+    <message>
+        <source>Seek backward</source>
+        <translation>خلف</translation>
+    </message>
+</context>
 <context>
     <name>ListModel</name>
     <message>
@@ -304,6 +454,42 @@
         <source>Your privacy is now safe</source>
         <translation>خصوصيتك امنة</translation>
     </message>
+    <message>
+        <source>&amp;Downloads</source>
+        <translation>&amp;التحميلات</translation>
+    </message>
+    <message>
+        <source>Show details about video downloads</source>
+        <translation>عرض تفاصيل عن تحميلات الفيديو</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation>&amp;التحميلات</translation>
+    </message>
+    <message>
+        <source>Download the current video</source>
+        <translation>تحميل الفيديو الحالي</translation>
+    </message>
+    <message>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation>هل تريد الخروج %1  رغم وجود تحميل?</translation>
+    </message>
+    <message>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation>عند اغلاق %1 التحميل سيلغى.</translation>
+    </message>
+    <message>
+        <source>Close and cancel download</source>
+        <translation>الاغلاق و الغاء التحميل</translation>
+    </message>
+    <message>
+        <source>Wait for download to finish</source>
+        <translation>انتظار انتهاء التحميل</translation>
+    </message>
+    <message>
+        <source>Downloads complete</source>
+        <translation>التحميل انتهى</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -337,19 +523,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>هذه ليست سوى النسخة التجريبية من %1.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>انها تتيح لك تجربة البرنامج.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>متابعة</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>احصل على النسخة الكاملة</translation>
+    </message>
+    <message>
+        <source>Downloading %1</source>
+        <translation>جاري تحميل %1</translation>
     </message>
 </context>
 <context>
@@ -365,6 +555,42 @@
         <source>%1 views</source>
         <translation>%1 مشاهدات</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) ? %4</source>
+        <translation>%1 of %2 (%3) ? %4</translation>
+    </message>
+    <message>
+        <source>Preparing</source>
+        <translation>تهيئة</translation>
+    </message>
+    <message>
+        <source>Failed</source>
+        <translation>فشل</translation>
+    </message>
+    <message>
+        <source>Completed</source>
+        <translation>تم</translation>
+    </message>
+    <message>
+        <source>Stopped</source>
+        <translation>متوقف</translation>
+    </message>
+    <message>
+        <source>Stop downloading</source>
+        <translation>ايقاف التحميل</translation>
+    </message>
+    <message>
+        <source>Show in %1</source>
+        <translation>اظهار في %1</translation>
+    </message>
+    <message>
+        <source>Open parent folder</source>
+        <translation>فتح المجلد الرئيسي</translation>
+    </message>
+    <message>
+        <source>Restart downloading</source>
+        <translation>اعادة التحميل</translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
