@@ -77,6 +77,152 @@
         <translation>Καθαρισμός</translation>
     </message>
 </context>
+<context>
+    <name>DownloadItem</name>
+    <message>
+        <source>bytes</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>KB</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>bytes/sec</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>KB/sec</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>MB/sec</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>seconds</source>
+        <translation>δευτερόλεπτα</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>λεπτά</translation>
+    </message>
+    <message>
+        <source>%4 %5 remaining</source>
+        <translation>απομένουν %4 %5</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadManager</name>
+    <message numerus="yes">
+        <source>%n Download(s)</source>
+        <translation>
+            <numerusform>%n Λήψεις</numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation>Αυτή είναι απλά η δοκιμαστική έκδοση του %1.</translation>
+    </message>
+    <message>
+        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
+        <translation>Μπορεί να κατεβάσει βίντεο μικρότερα από %1 λεπτά ώστε να δοκιμάσετε τη λειτουργία κατεβάσματος.</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Συνέχεια</translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Αποκτήστε την πλήρη έκδοση</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadSettings</name>
+    <message>
+        <source>Change location...</source>
+        <translation>Αλλάξτε τοποθεσία...</translation>
+    </message>
+    <message>
+        <source>Choose the download location</source>
+        <translation>Επιλέξτε την τοποθεσία λήψης</translation>
+    </message>
+    <message>
+        <source>Download location changed.</source>
+        <translation>Η τοποθεσία λήψης άλλαξε.</translation>
+    </message>
+    <message>
+        <source>Current downloads will still go in the previous location.</source>
+        <translation>Τα ήδη ληφθέντα θα παραμείνουν στην προηγούμενη τοποθεσία.</translation>
+    </message>
+    <message>
+        <source>Downloading to: %1</source>
+        <translation>Λήψη στο: %1</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadView</name>
+    <message>
+        <source>Downloads</source>
+        <translation>Λήψεις</translation>
+    </message>
+</context>
+<context>
+    <name>GlobalShortcuts</name>
+    <message>
+        <source>Play</source>
+        <translation>Αναπαραγωγή</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Παύση</translation>
+    </message>
+    <message>
+        <source>Play/Pause</source>
+        <translation>Αναπαραγωγή/Παύση</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Διακοπή</translation>
+    </message>
+    <message>
+        <source>Stop playing after current track</source>
+        <translation>Διακοπή αναπαραγωγής μετά το τρέχον κομμάτι</translation>
+    </message>
+    <message>
+        <source>Next track</source>
+        <translation>Επόμενο κομμάτι</translation>
+    </message>
+    <message>
+        <source>Previous track</source>
+        <translation>Προηγούμενο κομμάτι</translation>
+    </message>
+    <message>
+        <source>Increase volume</source>
+        <translation>Αύξηση έντασης</translation>
+    </message>
+    <message>
+        <source>Decrease volume</source>
+        <translation>Μείωση έντασης</translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation>Σίγαση</translation>
+    </message>
+    <message>
+        <source>Seek forward</source>
+        <translation>Αναζήτηση μπροστά</translation>
+    </message>
+    <message>
+        <source>Seek backward</source>
+        <translation>Αναζήτηση πίσω</translation>
+    </message>
+</context>
 <context>
     <name>ListModel</name>
     <message>
@@ -394,6 +540,42 @@
         <source>Maximum video definition set to %1</source>
         <translation>H μέγιστη ανάλυση βίντεο τέθηκε σε %1</translation>
     </message>
+    <message>
+        <source>&amp;Downloads</source>
+        <translation>&amp;Λήψεις</translation>
+    </message>
+    <message>
+        <source>Show details about video downloads</source>
+        <translation>Εμφάνιση λεπτομερειών για τις λήψεις βίντεο</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation>&amp;Λήψη</translation>
+    </message>
+    <message>
+        <source>Download the current video</source>
+        <translation>Λήψη του τρέχοντος βίντεο</translation>
+    </message>
+    <message>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation>Θέλετε να κλείσετε το %1 ενώ βρίσκεται μια λήψη σε εξέλιξη;</translation>
+    </message>
+    <message>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation>Αν κλείσετε το %1 τώρα, η λήψη θα ακυρωθεί.</translation>
+    </message>
+    <message>
+        <source>Close and cancel download</source>
+        <translation>Κλείσιμο και ακύρωση λήψης</translation>
+    </message>
+    <message>
+        <source>Wait for download to finish</source>
+        <translation>Αναμονή ολοκλήρωσης λήψης</translation>
+    </message>
+    <message>
+        <source>Downloads complete</source>
+        <translation>Οι λήψεις ολοκληρώθηκαν</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -427,19 +609,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Αυτή είναι απλά μια δοκιμαστική έκδοση του %1.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>Σαε επιτρέπει να δοκιμάσετε την εφαρμογή και να δείτε αν σας κάνει.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Συνέχεια</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Αποκτήστε την πλήρη έκδοση</translation>
+    </message>
+    <message>
+        <source>Downloading %1</source>
+        <translation>Λήψη %1</translation>
     </message>
 </context>
 <context>
@@ -455,6 +641,43 @@
         <source>%1 views</source>
         <translation>Προβολές %1</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) ? %4</source>
+        <translatorcomment>needed description of what this variables represent so it can be translated..</translatorcomment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preparing</source>
+        <translation>Προετοιμάζεται</translation>
+    </message>
+    <message>
+        <source>Failed</source>
+        <translation>Απέτυχε</translation>
+    </message>
+    <message>
+        <source>Completed</source>
+        <translation>Ολοκληρώθηκε</translation>
+    </message>
+    <message>
+        <source>Stopped</source>
+        <translation>Διακόπηκε</translation>
+    </message>
+    <message>
+        <source>Stop downloading</source>
+        <translation>Διακοπή λήψης</translation>
+    </message>
+    <message>
+        <source>Show in %1</source>
+        <translation>Εμφάνιση σε %1</translation>
+    </message>
+    <message>
+        <source>Open parent folder</source>
+        <translation>Άνοιγμα γονικού φακέλου</translation>
+    </message>
+    <message>
+        <source>Restart downloading</source>
+        <translation>Επανεκκίνηση λήψης</translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
