@@ -76,6 +76,153 @@
         <translation>Dzēst</translation>
     </message>
 </context>
+<context>
+    <name>DownloadItem</name>
+    <message>
+        <source>bytes</source>
+        <translation>baiti</translation>
+    </message>
+    <message>
+        <source>KB</source>
+        <translation>KB</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation>MB</translation>
+    </message>
+    <message>
+        <source>bytes/sec</source>
+        <translation>baiti sekundē</translation>
+    </message>
+    <message>
+        <source>KB/sec</source>
+        <translation>KB/s</translation>
+    </message>
+    <message>
+        <source>MB/sec</source>
+        <translation>MB/s</translation>
+    </message>
+    <message>
+        <source>seconds</source>
+        <translation>sekundes</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minūtes</translation>
+    </message>
+    <message>
+        <source>%4 %5 remaining</source>
+	<translation>%4 %5 paliek</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadManager</name>
+    <message numerus="yes">
+        <source>%n Download(s)</source>
+        <translation>
+		<numerusform>%n Lejupielāde(s)</numerusform>
+		<numerusform>%n Lejupielāde(s)</numerusform>
+		<numerusform>%n Lejupielāde(s)</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation>Šī ir %1 demo versija.</translation>
+    </message>
+    <message>
+        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
+        <translation>Tā spēj lejuplādēt tikai par %1 minūtēm īsākus klipus lai notestētu lejupielādes funkcionālitāti.</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Turpināt</translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Novilkt pilnu versiju</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadSettings</name>
+    <message>
+        <source>Change location...</source>
+        <translation>Mainīt mērķa mapi... </translation>
+    </message>
+    <message>
+        <source>Choose the download location</source>
+	<translation>Izvēlieties mērķa mapi</translation>
+    </message>
+    <message>
+        <source>Download location changed.</source>
+        <translation>Mērķa mape ir mainīta.</translation>
+    </message>
+    <message>
+        <source>Current downloads will still go in the previous location.</source>
+        <translation>Esošās lejupielādes tiks saglabātas iepriekšējā mapē.</translation>
+    </message>
+    <message>
+        <source>Downloading to: %1</source>
+        <translation>Lejuplādēju iekš: %1</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadView</name>
+    <message>
+        <source>Downloads</source>
+        <translation>Lejupielādes</translation>
+    </message>
+</context>
+<context>
+    <name>GlobalShortcuts</name>
+    <message>
+        <source>Play</source>
+        <translation>Atskaņot</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Apturēt</translation>
+    </message>
+    <message>
+        <source>Play/Pause</source>
+	<translation>Atskaņot / Apturēt</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Pārtraukt</translation>
+    </message>
+    <message>
+        <source>Stop playing after current track</source>
+	<translation>Pārtraukt atskaņošanu pēc šī klipa</translation>
+    </message>
+    <message>
+        <source>Next track</source>
+        <translation>Nākošais klips</translation>
+    </message>
+    <message>
+        <source>Previous track</source>
+        <translation>Iepriekšējais klips</translation>
+    </message>
+    <message>
+        <source>Increase volume</source>
+        <translation>Skaļāk</translation>
+    </message>
+    <message>
+        <source>Decrease volume</source>
+        <translation>Klusāk</translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation>Izslēgt skaņu</translation>
+    </message>
+    <message>
+        <source>Seek forward</source>
+        <translation>Pārtīt uz priekšu</translation>
+    </message>
+    <message>
+        <source>Seek backward</source>
+        <translation>Pārtīt atpakaļ</translation>
+    </message>
+</context>
 <context>
     <name>ListModel</name>
     <message>
@@ -356,6 +503,42 @@
         <source>Maximum video definition set to %1</source>
         <translation>Klipa maksimālā izšķirtspēja ir %1</translation>
     </message>
+    <message>
+        <source>&amp;Downloads</source>
+        <translation>Lejupielādes</translation>
+    </message>
+    <message>
+        <source>Show details about video downloads</source>
+        <translation>Rādīt klipu lejupielāžu detaļas</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation>Lejuplādēt</translation>
+    </message>
+    <message>
+        <source>Download the current video</source>
+	<translation>Lejuplādēt šo klipu</translation>
+    </message>
+    <message>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation>Vai vēlaties iziet no %1 neskatoties uz notiekošo lejupielādi?</translation>
+    </message>
+    <message>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation>Ja aizvērsit %1 tagad, šī lejupielāde tiks atcelta.</translation>
+    </message>
+    <message>
+        <source>Close and cancel download</source>
+        <translation>Aizvērt un atcelt lejupielādi</translation>
+    </message>
+    <message>
+        <source>Wait for download to finish</source>
+        <translation>Pagaidīt līdz lejupielādes beigām</translation>
+    </message>
+    <message>
+        <source>Downloads complete</source>
+        <translation>Lejupielādes pabeigtas</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -389,19 +572,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Šī ir %1 demo versija.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>Tā ļauj notestēt programmu un noskaidrot vai tā jums der.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Turpināt</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Novilkt pilnu versiju</translation>
+    </message>
+    <message>
+        <source>Downloading %1</source>
+        <translation>Lejuplādēju %1</translation>
     </message>
 </context>
 <context>
@@ -417,6 +604,42 @@
         <source>%1 views</source>
         <translation>%1 skatījumi</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) ? %4</source>
+	<translation>%1 no %2 (%3) ? %4</translation>
+    </message>
+    <message>
+        <source>Preparing</source>
+        <translation>Topošās</translation>
+    </message>
+    <message>
+        <source>Failed</source>
+        <translation>Neizdevušās</translation>
+    </message>
+    <message>
+        <source>Completed</source>
+        <translation>Pabeigtas</translation>
+    </message>
+    <message>
+        <source>Stopped</source>
+        <translation>Apturētas</translation>
+    </message>
+    <message>
+        <source>Stop downloading</source>
+        <translation>Pārtraukt lejupielādi</translation>
+    </message>
+    <message>
+        <source>Show in %1</source>
+        <translation>Rādīt %1</translation>
+    </message>
+    <message>
+        <source>Open parent folder</source>
+        <translation>Atvērt mapi līmeni augstāk</translation>
+    </message>
+    <message>
+        <source>Restart downloading</source>
+        <translation>Atsākt lejupielādi</translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
