@@ -76,6 +76,153 @@
         <translation>Wyczyść</translation>
     </message>
 </context>
+<context>
+    <name>DownloadItem</name>
+    <message>
+        <source>bytes</source>
+        <translation>bajtów</translation>
+    </message>
+    <message>
+        <source>KB</source>
+        <translation>KB</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation>MB</translation>
+    </message>
+    <message>
+        <source>bytes/sec</source>
+        <translation>bajtów/s</translation>
+    </message>
+    <message>
+        <source>KB/sec</source>
+        <translation>KB/s</translation>
+    </message>
+    <message>
+        <source>MB/sec</source>
+        <translation>MB/s</translation>
+    </message>
+    <message>
+        <source>seconds</source>
+        <translation>sekund</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minut</translation>
+    </message>
+    <message>
+        <source>%4 %5 remaining</source>
+        <translation>Pozostało %4 %5</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadManager</name>
+    <message numerus="yes">
+        <source>%n Download(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation>To tylko wersja demo %1.</translation>
+    </message>
+    <message>
+        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
+        <translation>Program pobiera tylko filmy krótsze od %1 minut w celu przetestowania funkcji.</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Kontynuuj</translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Zdobądź pełną wersję</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadSettings</name>
+    <message>
+        <source>Change location...</source>
+        <translation>Zmień położenie</translation>
+    </message>
+    <message>
+        <source>Choose the download location</source>
+        <translation>Wybierz położenie pobierań</translation>
+    </message>
+    <message>
+        <source>Download location changed.</source>
+        <translation>Udało się zmienić położenie pobranych filmów.</translation>
+    </message>
+    <message>
+        <source>Current downloads will still go in the previous location.</source>
+        <translation>Pobrane filmy nadal będą zapisywane w poprzedniej lokalizacji.</translation>
+    </message>
+    <message>
+        <source>Downloading to: %1</source>
+        <translation>Pobieranie do: %1</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadView</name>
+    <message>
+        <source>Downloads</source>
+        <translation>Pobrane filmy</translation>
+    </message>
+</context>
+<context>
+    <name>GlobalShortcuts</name>
+    <message>
+        <source>Play</source>
+        <translation>Odtwórz</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Wstrzymaj</translation>
+    </message>
+    <message>
+        <source>Play/Pause</source>
+        <translation>Odtwórz/Wstrzymaj</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Stop playing after current track</source>
+        <translation>Zakończ odtwarzanie po tym utworze</translation>
+    </message>
+    <message>
+        <source>Next track</source>
+        <translation>Następny utwór</translation>
+    </message>
+    <message>
+        <source>Previous track</source>
+        <translation>Poprzedni utwór</translation>
+    </message>
+    <message>
+        <source>Increase volume</source>
+        <translation>Zwiększ głośność</translation>
+    </message>
+    <message>
+        <source>Decrease volume</source>
+        <translation>Zmniejsz głośność</translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation>Wycisz</translation>
+    </message>
+    <message>
+        <source>Seek forward</source>
+        <translation>Przewiń do przodu</translation>
+    </message>
+    <message>
+        <source>Seek backward</source>
+        <translation>Przewiń do tyłu</translation>
+    </message>
+</context>
 <context>
     <name>ListModel</name>
     <message>
@@ -352,6 +499,42 @@
         <source>Maximum video definition set to %1</source>
         <translation>Aktualne ustawienie jakości wideo to %1</translation>
     </message>
+    <message>
+        <source>&amp;Downloads</source>
+        <translation>&amp;Pobrane pliku</translation>
+    </message>
+    <message>
+        <source>Show details about video downloads</source>
+        <translation>Pokaż szczegóły pobranych filmów</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation>&amp;Pobierz</translation>
+    </message>
+    <message>
+        <source>Download the current video</source>
+        <translation>Pobierz aktualnie odtwarzany film</translation>
+    </message>
+    <message>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation>Czy chcesz zamknąć %1 z uruchomionym procesem pobierania?</translation>
+    </message>
+    <message>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation>Jeśli zamkniesz %1, proces pobierania zostanie anulowany.</translation>
+    </message>
+    <message>
+        <source>Close and cancel download</source>
+        <translation>Zamknij i anuluj pobieranie</translation>
+    </message>
+    <message>
+        <source>Wait for download to finish</source>
+        <translation>Zaczekaj do końca pobierania</translation>
+    </message>
+    <message>
+        <source>Downloads complete</source>
+        <translation>Pobieranie zakończone</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -385,19 +568,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>To tylko wersja demo %1.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pozwala przetestować aplikację i sprawdzić, czy działa.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Kontynuuj</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Zdobądź pełną wersję.</translation>
+    </message>
+    <message>
+        <source>Downloading %1</source>
+        <translation>Pobieranie %1</translation>
     </message>
 </context>
 <context>
@@ -413,6 +600,42 @@
         <source>%1 views</source>
         <translation>%1 wyświetleń</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) ? %4</source>
+        <translation>%1 z %2 (%3) ? %4</translation>
+    </message>
+    <message>
+        <source>Preparing</source>
+        <translation>Przygotowywanie</translation>
+    </message>
+    <message>
+        <source>Failed</source>
+        <translation>Nie udało się</translation>
+    </message>
+    <message>
+        <source>Completed</source>
+        <translation>Zakończono</translation>
+    </message>
+    <message>
+        <source>Stopped</source>
+        <translation>Zatrzymano</translation>
+    </message>
+    <message>
+        <source>Stop downloading</source>
+        <translation>Zatrzymaj pobieranie</translation>
+    </message>
+    <message>
+        <source>Show in %1</source>
+        <translation>Pokaż w %1</translation>
+    </message>
+    <message>
+        <source>Open parent folder</source>
+        <translation>Otwórz nadrzędny folder</translation>
+    </message>
+    <message>
+        <source>Restart downloading</source>
+        <translation>Restartuj pobieranie</translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -460,7 +683,7 @@
     </message>
     <message>
         <source>Use high quality video when available</source>
-        <translation type="obsolete">Użyj wysokiej jakości wideo jeśli jest to możliwe</translation>
+        <translation type="obsolete">Użyj wysokiej jakości wideo, jeśli jest to możliwe</translation>
     </message>
     <message>
         <source>&amp;Saved recent keywords</source>
