@@ -64,6 +64,155 @@
         <translation>Limpar</translation>
     </message>
 </context>
+<context>
+    <name>DownloadItem</name>
+    <message>
+        <source>bytes</source>
+        <translation>bytes</translation>
+    </message>
+    <message>
+        <source>KB</source>
+        <translation>KB</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation>MB</translation>
+    </message>
+    <message>
+        <source>bytes/sec</source>
+        <translation>bytes/seg</translation>
+    </message>
+    <message>
+        <source>KB/sec</source>
+        <translation>KB/sec</translation>
+    </message>
+    <message>
+        <source>MB/sec</source>
+        <translation>MB/seg</translation>
+    </message>
+    <message>
+        <source>seconds</source>
+        <translation>segundos</translation>
+    </message>
+    <message>
+        <source>minutes</source>
+        <translation>minutos</translation>
+    </message>
+    <message>
+        <source>%4 %5 remaining</source>
+        <translation>%4 %5 restante</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadManager</name>
+    <message numerus="yes">
+        <source>%n Download(s)</source>
+        <translation>
+            <numerusform>%n Transferência</numerusform>
+            <numerusform>%n Transferências</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation>Isto é apenas uma versão de demonstração de %1.</translation>
+    </message>
+    <message>
+        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
+        <translation>Apenas pode transferir vídeos mais curtos que %1 minuto(s) de forma a testar a funcionalidade de transferência.</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continuar</translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation>Transfira a versão completa</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadSettings</name>
+    <message>
+        <source>Change location...</source>
+        <translatorcomment>soa melhor assim :)</translatorcomment>
+        <translation>Mudar pasta de destino...</translation>
+    </message>
+    <message>
+        <source>Choose the download location</source>
+        <translation>Escolha a pasta de destino da transferência</translation>
+    </message>
+    <message>
+        <source>Download location changed.</source>
+        <translation>A pasta de destino da transferência foi actualizada.</translation>
+    </message>
+    <message>
+        <source>Current downloads will still go in the previous location.</source>
+        <translation>A pasta de transferência actual irá manter-se na mesma pasta.</translation>
+    </message>
+    <message>
+        <source>Downloading to: %1</source>
+        <translation>A transferir para: %1</translation>
+    </message>
+</context>
+<context>
+    <name>DownloadView</name>
+    <message>
+        <source>Downloads</source>
+        <translation>Transferências</translation>
+    </message>
+</context>
+<context>
+    <name>GlobalShortcuts</name>
+    <message>
+        <source>Play</source>
+        <translatorcomment>vale a pena traduzir?</translatorcomment>
+        <translation>Iniciar</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Play/Pause</source>
+        <translation>Iniciar/Pausar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translatorcomment>vale a pena traduzir?</translatorcomment>
+        <translation>Parar</translation>
+    </message>
+    <message>
+        <source>Stop playing after current track</source>
+        <translation>Parar assim que terminar o vídeo ou música corrente</translation>
+    </message>
+    <message>
+        <source>Next track</source>
+        <translation>Próximo vídeo/música</translation>
+    </message>
+    <message>
+        <source>Previous track</source>
+        <translation>Vídeo/música anterior</translation>
+    </message>
+    <message>
+        <source>Increase volume</source>
+        <translation>Aumentar volume</translation>
+    </message>
+    <message>
+        <source>Decrease volume</source>
+        <translation>Diminuir volume</translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation>Silêncio</translation>
+    </message>
+    <message>
+        <source>Seek forward</source>
+        <translation>Avançar</translation>
+    </message>
+    <message>
+        <source>Seek backward</source>
+        <translation>Retroceder</translation>
+    </message>
+</context>
 <context>
     <name>ListModel</name>
     <message>
@@ -304,6 +453,42 @@
         <source>Your privacy is now safe</source>
         <translation>A sua privacidade está agora assegurada</translation>
     </message>
+    <message>
+        <source>&amp;Downloads</source>
+        <translation>&amp;Transferências</translation>
+    </message>
+    <message>
+        <source>Show details about video downloads</source>
+        <translation>Mostar detalhes sobre a transferência de vídeos</translation>
+    </message>
+    <message>
+        <source>&amp;Download</source>
+        <translation>&amp;Transferência</translation>
+    </message>
+    <message>
+        <source>Download the current video</source>
+        <translation>Transferir o vídeo actual</translation>
+    </message>
+    <message>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation>Deseja sair %1 com uma transferência activa?</translation>
+    </message>
+    <message>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation>Se fechar %1, a transferência irá ser cancelada.</translation>
+    </message>
+    <message>
+        <source>Close and cancel download</source>
+        <translation>Fechar e cancelar a transferência</translation>
+    </message>
+    <message>
+        <source>Wait for download to finish</source>
+        <translation>Espere que a transferência termine</translation>
+    </message>
+    <message>
+        <source>Downloads complete</source>
+        <translation>Transferência completa</translation>
+    </message>
 </context>
 <context>
     <name>MediaView</name>
@@ -337,19 +522,23 @@
     </message>
     <message>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Isto é apenas uma versão de demonstração de %1.</translation>
     </message>
     <message>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation>Permite testes a aplicacção e verificar como funciona.</translation>
     </message>
     <message>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation>Continuar</translation>
     </message>
     <message>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation>Transfira a versão completa</translation>
+    </message>
+    <message>
+        <source>Downloading %1</source>
+        <translation>Transferir: %1</translation>
     </message>
 </context>
 <context>
@@ -365,6 +554,42 @@
         <source>%1 views</source>
         <translation>%1 visualizações</translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3) ? %4</source>
+        <translation>%1 de %2 (%3) ? %4</translation>
+    </message>
+    <message>
+        <source>Preparing</source>
+        <translation>A preparar</translation>
+    </message>
+    <message>
+        <source>Failed</source>
+        <translation>Falhou</translation>
+    </message>
+    <message>
+        <source>Completed</source>
+        <translation>Completo</translation>
+    </message>
+    <message>
+        <source>Stopped</source>
+        <translation>Parado</translation>
+    </message>
+    <message>
+        <source>Stop downloading</source>
+        <translation>Parar a transferência</translation>
+    </message>
+    <message>
+        <source>Show in %1</source>
+        <translation>Mostrar em %1</translation>
+    </message>
+    <message>
+        <source>Open parent folder</source>
+        <translation>Abrir pasta anterior</translation>
+    </message>
+    <message>
+        <source>Restart downloading</source>
+        <translation>Recomeçar a transferência</translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
