@@ -2,9 +2,16 @@
 #include <qtsingleapplication.h>
 #include "constants.h"
 #include "MainWindow.h"
+#ifdef APP_MAC
+// #include "local/mac/mac_startup.h"
+#endif
 
 int main(int argc, char **argv) {
 
+#ifdef APP_MAC
+    // mac::MacMain();
+#endif
+
     QtSingleApplication app(argc, argv);
     if (app.sendMessage("Wake up!"))
         return 0;
@@ -30,12 +37,11 @@ int main(int argc, char **argv) {
 #else
     QString dataDir = "";
 #endif
-    QString localeDir = dataDir + QDir::separator() + "locale";
-    // if app was not "installed" use the app directory
+    QString localeDir = qApp->applicationDirPath() + QDir::separator() + "locale";
     if (!QFile::exists(localeDir)) {
-        localeDir = qApp->applicationDirPath() + QDir::separator() + "locale";
-        // qDebug() << "Using locale dir" << localeDir << locale;
+        localeDir = dataDir + QDir::separator() + "locale";
     }
+    // qDebug() << "Using locale dir" << localeDir << locale;
     QTranslator translator;
     translator.load(locale, localeDir);
     app.installTranslator(&translator);
